if (getRversion() >= "4.3") {
  utils::globalVariables(c(
    "cytokine", "level", "variance", "ssmd", "log2FC", "SSMD_Category", "Significant",
    "Component", "Variance", "Cumulative",
    "Variable", "Gini", "Variables", "Error",
    "value", "transformation",
    "ErrorRate", "Distance", "metabo",
    "significant", "label", "Value",
    "Measure", "p.value", "effect.size",
    "center", "spread"
  ))
}
